**Learning Objectives**:

*LO5a: Learn the characteristics of open software; understand the **ethical, legal, economic, and research impact arguments for and against open software**, and further understand the quality requirements of open code (knowledge).*

*LO5b: Be able to turn code made for personal use into open code which is accessible by others (task).*

*LO5c: Use software (tools) that utilizes open content (task).*

### Key components

-   Principles of Open Source Software.
-   What open, collaborative platforms, with version control, exist.
-   GitHub and Zenodo plug-in for code archiving.
-   How to document and publish code.
-   Open Source licensing.
-   Tools for better open research (e.g., RStudio).
-   Community codes, governance, and contributions.
-   How to access and start working on general computing platforms (e.g., GCE, AWS, OpenStack and more specific - Galaxy, InsideDNA).
-   Differences in setting up accounts/storage/computing on different platforms.
-   Comparison in terms of collaboration and openness with clusters/in-house servers.

### Who to involve

-   Individuals: Paola Masuzzo, Naomi Penfold, Titus Brown Rene Bernard, Daniel Katz, Neil Chue Hong, Heidi Seibold, Anna
    Kostikova.
-   Organisations: Sustainable Software Institute, COKO Foundation, [Free Software
    Foundation](https://www.fsf.org/licensing/).
-   Other: [WSSSPE community](hhttp://wssspe.researchcomputing.org.uk),
    editors of software peer-reviewed journals ([Open Research Software](http://openresearchsoftware.metajnl.com),
    [JOSS](http://joss.theoj.org)).
-   Testimonials of scientists who just published code explaining why they went through the trouble and of scientists who already use
    cloud computing. Explanations about large initiatives (e.g. TCGA) moving their data into cloud and why it has huge impact.

### Key resources:

#### Tools

-   [Journal of Open Research Software](https://openresearchsoftware.metajnl.com/) and the [Journal of Open Source Software](https://joss.theoj.org/).
-   [InsideDNA](https://insidedna.me/), [Galaxy](https://galaxyproject.org/) - Reproducible Research environments.
-   [Google Compute Engine](https://cloud.google.com/compute/) (GCE), [Amazon Web Services](https://aws.amazon.com/) (AWS) - Cloud-based software environments.
-   [Software Citation Tools](https://github.com/mozillascience/software-citation-tools), Mozilla Science Lab.
-   [Open Science, Open Data, Open Source](https://pfern.github.io/OSODOS/gitbook/) (Fernandes and Vos, 2017).
-   [Choose an open source license](https://choosealicense.com/).

#### Research Articles and Reports

-   [The Future of Research in Free/Open Source Software Development](http://www.ics.uci.edu/~wscacchi/Papers/New/FoSER-Scacchi-2010.pdf) (Scacchi, 2010).
-   [The Scientific Method in Practice: Reproducibility in the Computational Sciences](http://datascienceassn.org/sites/default/files/The%2520Scientific%2520Method%2520in%2520Practice%2520-%2520Reproducibility%2520in%2520the%2520Computational%2520Sciences.pdf) (Stodden, 2010).
-   [The case for open computer programs](https://www.nature.com/articles/nature10836) (Ince et al., 2012).
-   [Code Sharing Is Associated with Research Impact in Image Processing](https://infoscience.epfl.ch/record/206184/files/Vandewalle12.pdf) (Vandewalle, 2012).
-   [Current issues and research trends on open-source software communities](https://www.google.com/url?q=https://idus.us.es/xmlui/bitstream/handle/11441/32245/Current%2520issues%2520and%2520research%2520trends.pdf?sequence%3D1) (Martinez-Torres and Diaz-Fernandez, 2013).
-   [Ten simple rules for reproducible computational research](http://journals.plos.org/ploscompbiol/article?id%3D10.1371/journal.pcbi.1003285) (Sandve et al., 2013).
-   [Practices in source code sharing in astrophysics](https://arxiv.org/abs/1304.6780) (Shamir et al., 2013).
-   [A systematic literature review on the barriers faced by newcomers to open source software projects](http://igor.pro.br/publica/papers/IST_SysReview_PrePrint.pdf) (Steinmacher et al., 2014).
-   [Knowledge sharing in open source software communities: motivations and management](https://pdfs.semanticscholar.org/f2a2/c5129cf5656af7acc7ffaf84c9c9bafe72c5.pdf) (Iskoujina and Roberts, 2015).
-   [An open source pharma roadmap](http://journals.plos.org/plosmedicine/article?id%3D10.1371/journal.pmed.1002276) (Balasegaram et al., 2017).
-   [An introduction to Rocker: Docker containers for R](https://arxiv.org/abs/1710.03675) (Boettiger and Eddelbuettel, 2017).
-   [Upon the Shoulders of Giants: Open-Source Hardware and Software in Analytical Chemistry](https://pubs.acs.org/doi/abs/10.1021/acs.analchem.7b00485) (Dryden et al., 2017).
-   [Four simple recommendations to encourage best practices in research software](https://f1000research.com/articles/6-876/v1) (Jimanez  et al., 2017).
-   [Perspectives on Reproducibility and Sustainability of Open-Source Scientific Software from Seven Years of the Dedalus Project](https://arxiv.org/abs/1801.08200) (Oishi et al., 2018).
-   [Good enough practices in scientific computing](https://doi.org/10.1371/journal.pcbi.1005510) (Wilson et al. ,2017).

##### Posts

-   [A breakdown of FOSS \[Free and Open Source Software\] for students and researchers in academia](https://opensource.com/education/15/11/foss-academic-research), Lois Donnelly.
-   [Publish your computer code: it is good enough](http://www.nature.com/news/2010/101013/full/467753a.html), Nick Barnes.
-   [Making your code citable](https://guides.github.com/activities/citable-code/), GitHub Guides.
-   [FLOSS and FOSS](https://www.gnu.org/philosophy/floss-and-foss.en.html), Richard Stallman.

#### Other

-   [The Sustainable Software Institute](https://www.software.ac.uk/).
-   [The Science Code Manifesto](http://sciencecodemanifesto.org/).
-   [Software Carpentry](https://software-carpentry.org/).
-   Github's [Open Source Guide](https://opensource.guide/).
-   [Software Citation Principles](https://doi.org/10.7717/peerj-cs.86).
-   Open Source Initiative: [Licenses and Standards](https://opensource.org/licenses).
-   [Arduino](https://www.arduino.cc/) an open source electronics platform based on easy-to-use hardware and software.

### Tasks:

-   Set up a GitHub account, if you haven't already.
-   Share some of your code in a new repo.
-   Track changes as your research develops using version control.
-   Document everything done by creating a README file.
-   Make sure to select an appropriate license for your repo.
-   Archive your versioned code in Zenodo.
